@@ -21,7 +21,7 @@ Version 0.01
 
 =cut
 
-our $VERSION = '2.39';
+our $VERSION = '2.40';
 
 =head1 SYNOPSIS
 
@@ -88,6 +88,7 @@ sub go{
     my $dt1 = DateTime->now();
 
     $self->prepend_logfile("MAIN_");
+    $self->append_logfile(".log");
     $self->log($self->init_log);
     $self->mce->spawn;
 
@@ -147,6 +148,8 @@ sub parse_file_mce{
     $DB::single=2;
 }
 
+use Storable qw(dclone);
+
 sub process_lines{
     my $self = shift;
     my $line = shift;
@@ -161,6 +164,7 @@ sub process_lines{
         else{
             $self->log->info("Enqueuing command:\n".$self->cmd);
             #MCE
+            #$self->mce->send($self);
             $self->queue->enqueue($self->counter, $self->cmd);
             #Threads
             #                $self->run_command_threads;
@@ -203,6 +207,28 @@ sub process_lines{
     }
 }
 
+=head2 run_command_mce
+
+MCE knows which subcommand to use from Runner/MCE - object mce
+
+=cut
+
+use Data::Dumper;
+sub run_command_mce{
+    my $self = shift;
+
+    my $pid = $$;
+
+    $DB::single=2;
+
+    #Mce doesn't take exitcode to end
+    push(@{$self->jobref->[-1]}, $pid);
+    $self->_log_commands($pid);
+
+    return;
+}
+
+
 #use namespace::autoclean;
 1;
 
